@@ -5,7 +5,7 @@
 #'
 #' @param id.vec A vector of Lattes ids (e.g. id.vec <- c('K4723925J2', 'K4713546D3') )
 #' @param field.qualis Area of Qualis to get Qualis journal rankings (default equals NULL). Eg. area.qualis <- 'ECONOMIA'
-#' @param folder.dl Name of folder where to store xml files (default = tempdir())
+#'@param folder.dl Name of folder where to store xml files (default = tempdir())
 #'
 #' @return Returns a list with two components:
 #'  \describe{
@@ -30,7 +30,11 @@ gld_get_lattes_data <- function(id.vec,
   id.vec <- as.character(id.vec)
   n.char <- nchar(id.vec)
 
+  # Check length id
   if (any(n.char!=10)) {
+    cat(paste0('You have ids with less or more than 10 characters. ',
+               'You should check for the corresponding 10 char id in the _new_ Lattes website(http://lattes.cnpq.br/)',
+               '. Just search for the name of the scholar. Exiting now..') )
     stop('All ids should be 10 character long. Check your input for id.vec.')
   }
 
@@ -55,25 +59,34 @@ gld_get_lattes_data <- function(id.vec,
   # save tpesq (quietly, please)
   suppressWarnings({
     tpesq   <- do.call(args = lapply(my.l, function(x) x$tpesq)  , what = dplyr::bind_rows)
-    tpublic <- do.call(args = lapply(my.l, function(x) x$tpublic), what = dplyr::bind_rows)
+    tpublic.published <- do.call(args = lapply(my.l, function(x) x$tpublic.published), what = dplyr::bind_rows)
+    tpublic.accepted <- do.call(args = lapply(my.l, function(x) x$tpublic.accepted), what = dplyr::bind_rows)
     tsupervisions <- do.call(args = lapply(my.l, function(x) x$tsupervisions), what = dplyr::bind_rows)
     tbooks <- do.call(args = lapply(my.l, function(x) x$tbooks), what = dplyr::bind_rows)
+    tconferences <- do.call(args = lapply(my.l, function(x) x$tconferences), what = dplyr::bind_rows)
   })
 
   # do Qualis
   if (!(is.null(field.qualis ))) {
     df.qualis <- gld_get_qualis(field.qualis = field.qualis)
-    idx <- match(tpublic$ISSN, df.qualis$issn)
 
-    tpublic$qualis <- df.qualis$ranking[idx]
+    idx <- match(tpublic.published$ISSN, df.qualis$issn)
+    tpublic.published$qualis <- df.qualis$ranking[idx]
+
+    idx <- match(tpublic.accepted$ISSN, df.qualis$issn)
+    tpublic.accepted$qualis <- df.qualis$ranking[idx]
   }
 
   # do sjr
   df.sjr <- gld_get_SJR()
 
-  idx <- match(tpublic$ISSN, df.sjr$Issn)
-  tpublic$SJR <- df.sjr$SJR[idx]
-  tpublic$H.SJR <- df.sjr$`H index`[idx]
+  idx <- match(tpublic.published$ISSN, df.sjr$Issn)
+  tpublic.published$SJR <- df.sjr$SJR[idx]
+  tpublic.published$H.SJR <- df.sjr$`H index`[idx]
+
+  idx <- match(tpublic.accepted$ISSN, df.sjr$Issn)
+  tpublic.accepted$SJR <- df.sjr$SJR[idx]
+  tpublic.accepted$H.SJR <- df.sjr$`H index`[idx]
 
   # fix datatypes
 
@@ -85,13 +98,19 @@ gld_get_lattes_data <- function(id.vec,
     tpesq$minor.field    <- as.character(tpesq$minor.field)
     tpesq$country.origin <- as.character(tpesq$country.origin)
 
-    tpublic$name         <- as.character(tpublic$name)
-    tpublic$year         <- as.numeric(tpublic$year)
-    tpublic$language     <- as.character(tpublic$language)
-    tpublic$start.page   <- as.numeric(tpublic$start.page)
-    tpublic$end.page     <- as.numeric(tpublic$end.page)
-    tpublic$order.aut    <- as.numeric(tpublic$order.aut)
-    tpublic$n.authors    <- as.numeric(tpublic$n.authors)
+    tpublic.published$name         <- as.character(tpublic.published$name)
+    tpublic.published$year         <- as.numeric(tpublic.published$year)
+    tpublic.published$language     <- as.character(tpublic.published$language)
+    #tpublic.published$start.page   <- as.numeric(tpublic.published$start.page)
+    #tpublic.published$end.page     <- as.numeric(tpublic.published$end.page)
+    tpublic.published$order.aut    <- as.numeric(tpublic.published$order.aut)
+    tpublic.published$n.authors    <- as.numeric(tpublic.published$n.authors)
+
+    tpublic.accepted$name         <- as.character(tpublic.accepted$name)
+    tpublic.accepted$year         <- as.numeric(tpublic.accepted$year)
+    tpublic.accepted$language     <- as.character(tpublic.accepted$language)
+    tpublic.accepted$order.aut    <- as.numeric(tpublic.accepted$order.aut)
+    tpublic.accepted$n.authors    <- as.numeric(tpublic.accepted$n.authors)
 
 
   })
@@ -105,19 +124,29 @@ gld_get_lattes_data <- function(id.vec,
   tpesq <- as.data.frame(lapply(tpesq, my.enc.fct),
                          stringsAsFactors = F)
 
-  tpublic <- as.data.frame(lapply(tpublic, my.enc.fct),
+  tpublic.published <- as.data.frame(lapply(tpublic.published, my.enc.fct),
                            stringsAsFactors = F)
 
+  tpublic.accepted <- as.data.frame(lapply(tpublic.accepted, my.enc.fct),
+                             stringsAsFactors = F)
+
   tsupervisions <- as.data.frame(lapply(tsupervisions, my.enc.fct),
                            stringsAsFactors = F)
 
   tbooks <- as.data.frame(lapply(tbooks, my.enc.fct),
                                  stringsAsFactors = F)
 
+  tconferences <- as.data.frame(lapply(tconferences, my.enc.fct),
+                             stringsAsFactors = F)
+
   # return data
-  l.out <- list(tpesq = tpesq, tpublic = tpublic,
+  l.out <- list(tpesq = tpesq,
+                tpublic.published = tpublic.published,
+                tpublic.accepted = tpublic.accepted,
                 tsupervisions = tsupervisions,
-                tbooks = tbooks)
+                tbooks = tbooks,
+                tconferences = tconferences)
+
   return(l.out)
 
 }
