@@ -2,8 +2,7 @@
 library(GetLattesData)
 
 # ids from EA-UFRGS
-my.ids <- c('K4713546D3', 'K4440252H7', 
-            'K4783858A0', 'K4723925J2')
+my.ids <- c('K4713546D3', 'K4440252H7', 'K4723925J2')
 
 # qualis for the field of management
 field.qualis = 'ADMINISTRAÇÃO PÚBLICA E DE EMPRESAS, CIÊNCIAS CONTÁBEIS E TURISMO'
@@ -18,17 +17,14 @@ tpesq <- l.out$tpesq
 str(tpesq)
 
 ## ------------------------------------------------------------------------
-tpublic <- l.out$tpublic
-str(tpublic)
+dplyr::glimpse(l.out$tpublic.published)
 
 ## ------------------------------------------------------------------------
-tsupervisions <- l.out$tsupervisions
-str(tsupervisions)
+tpublic.published <- l.out$tpublic.published
 
-## ------------------------------------------------------------------------
 library(ggplot2)
 
-p <- ggplot(tpublic, aes(x = qualis)) +
+p <- ggplot(tpublic.published, aes(x = qualis)) +
   geom_bar(position = 'identity') + facet_wrap(~name) +
   labs(x = paste0('Qualis: ', field.qualis))
 print(p)
@@ -36,7 +32,7 @@ print(p)
 ## ------------------------------------------------------------------------
 library(dplyr)
 
-my.tab <- tpublic %>%
+my.tab <- tpublic.published %>%
   group_by(name) %>%
   summarise(n.papers = n(),
             max.SJR = max(SJR, na.rm = T),
